==> portal-service-6.0.2-sources.jar: com/liferay/portal/kernel/util/ArrayUtil_IW.java <==
/**
 * Copyright (c) 2000-2010 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.portal.kernel.util;

/**
 * <a href="ArrayUtil_IW.java.html"><b><i>View Source</i></b></a>
 *
 * @author Brian Wing Shun Chan
 */
public class ArrayUtil_IW {
	public static ArrayUtil_IW getInstance() {
		return _instance;
	}

	public boolean[] append(boolean[]... arrays) {
		return ArrayUtil.append(arrays);
	}

	public boolean[] append(boolean[] array, boolean value) {
		return ArrayUtil.append(array, value);
	}

	public java.lang.Boolean[] append(java.lang.Boolean[]... arrays) {
		return ArrayUtil.append(arrays);
	}

	public java.lang.Boolean[] append(java.lang.Boolean[] array,
		java.lang.Boolean value) {
		return ArrayUtil.append(array, value);
	}

	public byte[] append(byte[]... arrays) {
		return ArrayUtil.append(arrays);
	}

	public byte[] append(byte[] array, byte value) {
		return ArrayUtil.append(array, value);
	}

	public java.lang.Byte[] append(java.lang.Byte[]... arrays) {
		return ArrayUtil.append(arrays);
	}

	public java.lang.Byte[] append(java.lang.Byte[] array, java.lang.Byte value) {
		return ArrayUtil.append(array, value);
	}

	public char[] append(char[]... arrays) {
		return ArrayUtil.append(arrays);
	}

	public char[] append(char[] array, char value) {
		return ArrayUtil.append(array, value);
	}

	public java.lang.Character[] append(java.lang.Character[]... arrays) {
		return ArrayUtil.append(arrays);
	}

	public java.lang.Character[] append(java.lang.Character[] array,
		java.lang.Character value) {
		return ArrayUtil.append(array, value);
	}

	public double[] append(double[]... arrays) {
		return ArrayUtil.append(arrays);
	}

	public double[] append(double[] array, double value) {
		return ArrayUtil.append(array, value);
	}

	public java.lang.Double[] append(java.lang.Double[]... arrays) {
		return ArrayUtil.append(arrays);
	}

	public java.lang.Double[] append(java.lang.Double[] array,
		java.lang.Double value) {
		return ArrayUtil.append(array, value);
	}

	public float[] append(float[]... arrays) {
		return ArrayUtil.append(arrays);
	}

	public float[] append(float[] array, float value) {
		return ArrayUtil.append(array, value);
	}

	public java.lang.Float[] append(java.lang.Float[]... arrays) {
		return ArrayUtil.append(arrays);
	}

	public java.lang.Float[] append(java.lang.Float[] array,
		java.lang.Float value) {
		return ArrayUtil.append(array, value);
	}

	public int[] append(int[]... arrays) {
		return ArrayUtil.append(arrays);
	}

	public int[] append(int[] array, int value) {
		return ArrayUtil.append(array, value);
	}

	public java.lang.Integer[] append(java.lang.Integer[]... arrays) {
		return ArrayUtil.append(arrays);
	}

	public java.lang.Integer[] append(java.lang.Integer[] array,
		java.lang.Integer value) {
		return ArrayUtil.append(array, value);
	}

	public long[] append(long[]... arrays) {
		return ArrayUtil.append(arrays);
	}

	public long[] append(long[] array, long value) {
		return ArrayUtil.append(array, value);
	}

	public java.lang.Long[] append(java.lang.Long[]... arrays) {
		return ArrayUtil.append(arrays);
	}

	public java.lang.Long[] append(java.lang.Long[] array, java.lang.Long value) {
		return ArrayUtil.append(array, value);
	}

	public java.lang.Object[] append(java.lang.Object[] array,
		java.lang.Object value) {
		return ArrayUtil.append(array, value);
	}

	public java.lang.Object[] append(java.lang.Object[] array1,
		java.lang.Object[] array2) {
		return ArrayUtil.append(array1, array2);
	}

	public java.lang.Object[][] append(java.lang.Object[][] array,
		java.lang.Object[] value) {
		return ArrayUtil.append(array, value);
	}

	public java.lang.Object[][] append(java.lang.Object[][] array1,
		java.lang.Object[][] array2) {
		return ArrayUtil.append(array1, array2);
	}

	public short[] append(short[]... arrays) {
		return ArrayUtil.append(arrays);
	}

	public short[] append(short[] array, short value) {
		return ArrayUtil.append(array, value);
	}

	public java.lang.Short[] append(java.lang.Short[]... arrays) {
		return ArrayUtil.append(arrays);
	}

	public java.lang.Short[] append(java.lang.Short[] array,
		java.lang.Short value) {
		return ArrayUtil.append(array, value);
	}

	public java.lang.String[] append(java.lang.String[] array,
		java.lang.String value) {
		return ArrayUtil.append(array, value);
	}

	public java.lang.String[] append(java.lang.String[] array1,
		java.lang.String[] array2) {
		return ArrayUtil.append(array1, array2);
	}

	public java.lang.String[][] append(java.lang.String[][] array,
		java.lang.String[] value) {
		return ArrayUtil.append(array, value);
	}

	public java.lang.String[][] append(java.lang.String[][] array1,
		java.lang.String[][] array2) {
		return ArrayUtil.append(array1, array2);
	}

	public boolean[] clone(boolean[] array) {
		return ArrayUtil.clone(array);
	}

	public java.lang.Boolean[] clone(java.lang.Boolean[] array) {
		return ArrayUtil.clone(array);
	}

	public byte[] clone(byte[] array) {
		return ArrayUtil.clone(array);
	}

	public java.lang.Byte[] clone(java.lang.Byte[] array) {
		return ArrayUtil.clone(array);
	}

	public char[] clone(char[] array) {
		return ArrayUtil.clone(array);
	}

	public java.lang.Character[] clone(java.lang.Character[] array) {
		return ArrayUtil.clone(array);
	}

	public double[] clone(double[] array) {
		return ArrayUtil.clone(array);
	}

	public java.lang.Double[] clone(java.lang.Double[] array) {
		return ArrayUtil.clone(array);
	}

	public float[] clone(float[] array) {
		return ArrayUtil.clone(array);
	}

	public java.lang.Float[] clone(java.lang.Float[] array) {
		return ArrayUtil.clone(array);
	}

	public int[] clone(int[] array) {
		return ArrayUtil.clone(array);
	}

	public java.lang.Integer[] clone(java.lang.Integer[] array) {
		return ArrayUtil.clone(array);
	}

	public long[] clone(long[] array) {
		return ArrayUtil.clone(array);
	}

	public java.lang.Long[] clone(java.lang.Long[] array) {
		return ArrayUtil.clone(array);
	}

	public java.lang.Object[] clone(java.lang.Object[] array) {
		return ArrayUtil.clone(array);
	}

	public java.lang.Object[][] clone(java.lang.Object[][] array) {
		return ArrayUtil.clone(array);
	}

	public short[] clone(short[] array) {
		return ArrayUtil.clone(array);
	}

	public java.lang.Short[] clone(java.lang.Short[] array) {
		return ArrayUtil.clone(array);
	}

	public java.lang.String[] clone(java.lang.String[] array) {
		return ArrayUtil.clone(array);
	}

	public java.lang.String[][] clone(java.lang.String[][] array) {
		return ArrayUtil.clone(array);
	}

	public void combine(java.lang.Object[] array1, java.lang.Object[] array2,
		java.lang.Object[] combinedArray) {
		ArrayUtil.combine(array1, array2, combinedArray);
	}

	public boolean contains(boolean[] array, boolean value) {
		return ArrayUtil.contains(array, value);
	}

	public boolean contains(byte[] array, byte value) {
		return ArrayUtil.contains(array, value);
	}

	public boolean contains(char[] array, char value) {
		return ArrayUtil.contains(array, value);
	}

	public boolean contains(double[] array, double value) {
		return ArrayUtil.contains(array, value);
	}

	public boolean contains(int[] array, int value) {
		return ArrayUtil.contains(array, value);
	}

	public boolean contains(long[] array, long value) {
		return ArrayUtil.contains(array, value);
	}

	public boolean contains(java.lang.Object[] array, java.lang.Object value) {
		return ArrayUtil.contains(array, value);
	}

	public boolean contains(short[] array, short value) {
		return ArrayUtil.contains(array, value);
	}

	public java.lang.String[] distinct(java.lang.String[] array) {
		return ArrayUtil.distinct(array);
	}

	public java.lang.String[] distinct(java.lang.String[] array,
		java.util.Comparator<java.lang.String> comparator) {
		return ArrayUtil.distinct(array, comparator);
	}

	public int getLength(java.lang.Object[] array) {
		return ArrayUtil.getLength(array);
	}

	public java.lang.Object getValue(java.lang.Object[] array, int pos) {
		return ArrayUtil.getValue(array, pos);
	}

	public boolean[] remove(boolean[] array, boolean value) {
		return ArrayUtil.remove(array, value);
	}

	public byte[] remove(byte[] array, byte value) {
		return ArrayUtil.remove(array, value);
	}

	public char[] remove(char[] array, char value) {
		return ArrayUtil.remove(array, value);
	}

	public double[] remove(double[] array, double value) {
		return ArrayUtil.remove(array, value);
	}

	public int[] remove(int[] array, int value) {
		return ArrayUtil.remove(array, value);
	}

	public long[] remove(long[] array, long value) {
		return ArrayUtil.remove(array, value);
	}

	public short[] remove(short[] array, short value) {
		return ArrayUtil.remove(array, value);
	}

	public java.lang.String[] remove(java.lang.String[] array,
		java.lang.String value) {
		return ArrayUtil.remove(array, value);
	}

	public java.lang.String[] removeByPrefix(java.lang.String[] array,
		java.lang.String prefix) {
		return ArrayUtil.removeByPrefix(array, prefix);
	}

	public void reverse(java.lang.String[] array) {
		ArrayUtil.reverse(array);
	}

	public java.lang.Boolean[] toArray(boolean[] array) {
		return ArrayUtil.toArray(array);
	}

	public boolean[] toArray(java.lang.Boolean[] array) {
		return ArrayUtil.toArray(array);
	}

	public java.lang.Byte[] toArray(byte[] array) {
		return ArrayUtil.toArray(array);
	}

	public byte[] toArray(java.lang.Byte[] array) {
		return ArrayUtil.toArray(array);
	}

	public java.lang.Character[] toArray(char[] array) {
		return ArrayUtil.toArray(array);
	}

	public char[] toArray(java.lang.Character[] array) {
		return ArrayUtil.toArray(array);
	}

	public java.lang.Double[] toArray(double[] array) {
		return ArrayUtil.toArray(array);
	}

	public double[] toArray(java.lang.Double[] array) {
		return ArrayUtil.toArray(array);
	}

	public java.lang.Float[] toArray(float[] array) {
		return ArrayUtil.toArray(array);
	}

	public float[] toArray(java.lang.Float[] array) {
		return ArrayUtil.toArray(array);
	}

	public java.lang.Integer[] toArray(int[] array) {
		return ArrayUtil.toArray(array);
	}

	public int[] toArray(java.lang.Integer[] array) {
		return ArrayUtil.toArray(array);
	}

	public java.lang.Long[] toArray(long[] array) {
		return ArrayUtil.toArray(array);
	}

	public long[] toArray(java.lang.Long[] array) {
		return ArrayUtil.toArray(array);
	}

	public java.lang.Short[] toArray(short[] array) {
		return ArrayUtil.toArray(array);
	}

	public short[] toArray(java.lang.Short[] array) {
		return ArrayUtil.toArray(array);
	}

	public java.lang.String[] toStringArray(boolean[] array) {
		return ArrayUtil.toStringArray(array);
	}

	public java.lang.String[] toStringArray(byte[] array) {
		return ArrayUtil.toStringArray(array);
	}

	public java.lang.String[] toStringArray(char[] array) {
		return ArrayUtil.toStringArray(array);
	}

	public java.lang.String[] toStringArray(java.util.Date[] array,
		java.text.DateFormat df) {
		return ArrayUtil.toStringArray(array, df);
	}

	public java.lang.String[] toStringArray(double[] array) {
		return ArrayUtil.toStringArray(array);
	}

	public java.lang.String[] toStringArray(float[] array) {
		return ArrayUtil.toStringArray(array);
	}

	public java.lang.String[] toStringArray(int[] array) {
		return ArrayUtil.toStringArray(array);
	}

	public java.lang.String[] toStringArray(
		com.liferay.portal.kernel.json.JSONArray array) {
		return ArrayUtil.toStringArray(array);
	}

	public java.lang.String[] toStringArray(long[] array) {
		return ArrayUtil.toStringArray(array);
	}

	public java.lang.String[] toStringArray(java.lang.Object[] array) {
		return ArrayUtil.toStringArray(array);
	}

	public java.lang.String[] toStringArray(short[] array) {
		return ArrayUtil.toStringArray(array);
	}

	private ArrayUtil_IW() {
	}

	private static ArrayUtil_IW _instance = new ArrayUtil_IW();
}

==> portal-service-6.0.5-sources.jar: com/liferay/portal/kernel/util/ArrayUtil_IW.java <==
/**
 * Copyright (c) 2000-2010 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.portal.kernel.util;

/**
 * @author Brian Wing Shun Chan
 */
public class ArrayUtil_IW {
	public static ArrayUtil_IW getInstance() {
		return _instance;
	}

	public boolean[] append(boolean[]... arrays) {
		return ArrayUtil.append(arrays);
	}

	public boolean[] append(boolean[] array, boolean value) {
		return ArrayUtil.append(array, value);
	}

	public byte[] append(byte[]... arrays) {
		return ArrayUtil.append(arrays);
	}

	public byte[] append(byte[] array, byte value) {
		return ArrayUtil.append(array, value);
	}

	public char[] append(char[]... arrays) {
		return ArrayUtil.append(arrays);
	}

	public char[] append(char[] array, char value) {
		return ArrayUtil.append(array, value);
	}

	public double[] append(double[]... arrays) {
		return ArrayUtil.append(arrays);
	}

	public double[] append(double[] array, double value) {
		return ArrayUtil.append(array, value);
	}

	public float[] append(float[]... arrays) {
		return ArrayUtil.append(arrays);
	}

	public float[] append(float[] array, float value) {
		return ArrayUtil.append(array, value);
	}

	public int[] append(int[]... arrays) {
		return ArrayUtil.append(arrays);
	}

	public int[] append(int[] array, int value) {
		return ArrayUtil.append(array, value);
	}

	public long[] append(long[]... arrays) {
		return ArrayUtil.append(arrays);
	}

	public long[] append(long[] array, long value) {
		return ArrayUtil.append(array, value);
	}

	public short[] append(short[]... arrays) {
		return ArrayUtil.append(arrays);
	}

	public short[] append(short[] array, short value) {
		return ArrayUtil.append(array, value);
	}

	public <T> T[] append(T[]... arrays) {
		return ArrayUtil.append(arrays);
	}

	public <T> T[] append(T[] array, T value) {
		return ArrayUtil.append(array, value);
	}

	public <T> T[] append(T[] array1, T[] array2) {
		return ArrayUtil.append(array1, array2);
	}

	public <T> T[][] append(T[][] array1, T[] value) {
		return ArrayUtil.append(array1, value);
	}

	public <T> T[][] append(T[][] array1, T[][] array2) {
		return ArrayUtil.append(array1, array2);
	}

	public boolean[] clone(boolean[] array) {
		return ArrayUtil.clone(array);
	}

	public byte[] clone(byte[] array) {
		return ArrayUtil.clone(array);
	}

	public char[] clone(char[] array) {
		return ArrayUtil.clone(array);
	}

	public double[] clone(double[] array) {
		return ArrayUtil.clone(array);
	}

	public float[] clone(float[] array) {
		return ArrayUtil.clone(array);
	}

	public int[] clone(int[] array) {
		return ArrayUtil.clone(array);
	}

	public long[] clone(long[] array) {
		return ArrayUtil.clone(array);
	}

	public short[] clone(short[] array) {
		return ArrayUtil.clone(array);
	}

	public <T> T[] clone(T[] array) {
		return ArrayUtil.clone(array);
	}

	public <T> T[][] clone(T[][] array) {
		return ArrayUtil.clone(array);
	}

	public void combine(java.lang.Object[] array1, java.lang.Object[] array2,
		java.lang.Object[] combinedArray) {
		ArrayUtil.combine(array1, array2, combinedArray);
	}

	public boolean contains(boolean[] array, boolean value) {
		return ArrayUtil.contains(array, value);
	}

	public boolean contains(byte[] array, byte value) {
		return ArrayUtil.contains(array, value);
	}

	public boolean contains(char[] array, char value) {
		return ArrayUtil.contains(array, value);
	}

	public boolean contains(double[] array, double value) {
		return ArrayUtil.contains(array, value);
	}

	public boolean contains(int[] array, int value) {
		return ArrayUtil.contains(array, value);
	}

	public boolean contains(long[] array, long value) {
		return ArrayUtil.contains(array, value);
	}

	public boolean contains(java.lang.Object[] array, java.lang.Object value) {
		return ArrayUtil.contains(array, value);
	}

	public boolean contains(short[] array, short value) {
		return ArrayUtil.contains(array, value);
	}

	public java.lang.String[] distinct(java.lang.String[] array) {
		return ArrayUtil.distinct(array);
	}

	public java.lang.String[] distinct(java.lang.String[] array,
		java.util.Comparator<java.lang.String> comparator) {
		return ArrayUtil.distinct(array, comparator);
	}

	public int getLength(java.lang.Object[] array) {
		return ArrayUtil.getLength(array);
	}

	public java.lang.Object getValue(java.lang.Object[] array, int pos) {
		return ArrayUtil.getValue(array, pos);
	}

	public boolean[] remove(boolean[] array, boolean value) {
		return ArrayUtil.remove(array, value);
	}

	public byte[] remove(byte[] array, byte value) {
		return ArrayUtil.remove(array, value);
	}

	public char[] remove(char[] array, char value) {
		return ArrayUtil.remove(array, value);
	}

	public double[] remove(double[] array, double value) {
		return ArrayUtil.remove(array, value);
	}

	public int[] remove(int[] array, int value) {
		return ArrayUtil.remove(array, value);
	}

	public long[] remove(long[] array, long value) {
		return ArrayUtil.remove(array, value);
	}

	public short[] remove(short[] array, short value) {
		return ArrayUtil.remove(array, value);
	}

	public java.lang.String[] remove(java.lang.String[] array,
		java.lang.String value) {
		return ArrayUtil.remove(array, value);
	}

	public java.lang.String[] removeByPrefix(java.lang.String[] array,
		java.lang.String prefix) {
		return ArrayUtil.removeByPrefix(array, prefix);
	}

	public void reverse(java.lang.String[] array) {
		ArrayUtil.reverse(array);
	}

	public java.lang.Boolean[] toArray(boolean[] array) {
		return ArrayUtil.toArray(array);
	}

	public boolean[] toArray(java.lang.Boolean[] array) {
		return ArrayUtil.toArray(array);
	}

	public java.lang.Byte[] toArray(byte[] array) {
		return ArrayUtil.toArray(array);
	}

	public byte[] toArray(java.lang.Byte[] array) {
		return ArrayUtil.toArray(array);
	}

	public java.lang.Character[] toArray(char[] array) {
		return ArrayUtil.toArray(array);
	}

	public char[] toArray(java.lang.Character[] array) {
		return ArrayUtil.toArray(array);
	}

	public java.lang.Double[] toArray(double[] array) {
		return ArrayUtil.toArray(array);
	}

	public double[] toArray(java.lang.Double[] array) {
		return ArrayUtil.toArray(array);
	}

	public java.lang.Float[] toArray(float[] array) {
		return ArrayUtil.toArray(array);
	}

	public float[] toArray(java.lang.Float[] array) {
		return ArrayUtil.toArray(array);
	}

	public java.lang.Integer[] toArray(int[] array) {
		return ArrayUtil.toArray(array);
	}

	public int[] toArray(java.lang.Integer[] array) {
		return ArrayUtil.toArray(array);
	}

	public java.lang.Long[] toArray(long[] array) {
		return ArrayUtil.toArray(array);
	}

	public long[] toArray(java.lang.Long[] array) {
		return ArrayUtil.toArray(array);
	}

	public java.lang.Short[] toArray(short[] array) {
		return ArrayUtil.toArray(array);
	}

	public short[] toArray(java.lang.Short[] array) {
		return ArrayUtil.toArray(array);
	}

	public java.lang.String[] toStringArray(boolean[] array) {
		return ArrayUtil.toStringArray(array);
	}

	public java.lang.String[] toStringArray(byte[] array) {
		return ArrayUtil.toStringArray(array);
	}

	public java.lang.String[] toStringArray(char[] array) {
		return ArrayUtil.toStringArray(array);
	}

	public java.lang.String[] toStringArray(java.util.Date[] array,
		java.text.DateFormat df) {
		return ArrayUtil.toStringArray(array, df);
	}

	public java.lang.String[] toStringArray(double[] array) {
		return ArrayUtil.toStringArray(array);
	}

	public java.lang.String[] toStringArray(float[] array) {
		return ArrayUtil.toStringArray(array);
	}

	public java.lang.String[] toStringArray(int[] array) {
		return ArrayUtil.toStringArray(array);
	}

	public java.lang.String[] toStringArray(
		com.liferay.portal.kernel.json.JSONArray array) {
		return ArrayUtil.toStringArray(array);
	}

	public java.lang.String[] toStringArray(long[] array) {
		return ArrayUtil.toStringArray(array);
	}

	public java.lang.String[] toStringArray(java.lang.Object[] array) {
		return ArrayUtil.toStringArray(array);
	}

	public java.lang.String[] toStringArray(short[] array) {
		return ArrayUtil.toStringArray(array);
	}

	private ArrayUtil_IW() {
	}

	private static ArrayUtil_IW _instance = new ArrayUtil_IW();
}
